pub struct ObstacleAlert {
pub obstacle_id: u64,
pub distance: f32,
pub direction: [f32; 3],
pub severity: AlertSeverity,
}Expand description
An alert generated when an obstacle is within a safety threshold.
Fields
obstacle_id: u64Identifier of the obstacle that triggered the alert.
distance: f32Distance to the obstacle in metres.
direction: [f32; 3]Unit direction vector pointing from the robot towards the obstacle.
severity: AlertSeveritySeverity of this alert.