pub struct SceneGraphBuilder { /* private fields */ }Expand description
Builds a SceneGraph from detected obstacles or raw point clouds.
The builder clusters scene objects, computes spatial edges between nearby objects, and produces a timestamped scene graph.
Implementations
Sourceimpl SceneGraphBuilder
impl SceneGraphBuilder
Sourcepub fn new(edge_distance_threshold: f64, max_objects: usize) -> Self
pub fn new(edge_distance_threshold: f64, max_objects: usize) -> Self
Create a new builder with explicit parameters.
Sourcepub fn build(&self, objects: Vec<SceneObject>, timestamp: i64) -> SceneGraph
pub fn build(&self, objects: Vec<SceneObject>, timestamp: i64) -> SceneGraph
Build a scene graph from a list of SceneObjects.
Edges are created between every pair of objects whose centers are within
edge_distance_threshold.
Sourcepub fn build_from_obstacles(
&self,
obstacles: &[DetectedObstacle],
timestamp: i64,
) -> SceneGraph
pub fn build_from_obstacles( &self, obstacles: &[DetectedObstacle], timestamp: i64, ) -> SceneGraph
Build a scene graph from detected obstacles.
Sourcepub fn merge(&self, a: &SceneGraph, b: &SceneGraph) -> SceneGraph
pub fn merge(&self, a: &SceneGraph, b: &SceneGraph) -> SceneGraph
Merge two scene graphs into one, re-computing edges.