pub struct PointCloudSceneGraphBuilder { /* private fields */ }Expand description
Builds SceneGraph instances from point clouds or pre-classified
object lists using spatial-hash clustering with union-find.
Implementations
Sourceimpl PointCloudSceneGraphBuilder
impl PointCloudSceneGraphBuilder
Sourcepub fn new(config: SceneGraphConfig) -> Self
pub fn new(config: SceneGraphConfig) -> Self
Create a new builder with the given configuration.
Sourcepub fn build_from_point_cloud(&self, cloud: &PointCloud) -> SceneGraph
pub fn build_from_point_cloud(&self, cloud: &PointCloud) -> SceneGraph
Build a scene graph by clustering a raw point cloud.
- Points are discretised into a spatial hash grid.
- Adjacent cells are merged via union-find.
- Each cluster above
min_cluster_sizebecomes aSceneObject. - Edges are created between objects whose centres are within
edge_distance_threshold.
Sourcepub fn build_from_objects(&self, objects: &[SceneObject]) -> SceneGraph
pub fn build_from_objects(&self, objects: &[SceneObject]) -> SceneGraph
Build a scene graph from a pre-existing list of objects.
Edges are created between objects whose centres are within
edge_distance_threshold.
Sourcepub fn merge_scenes(&self, scenes: &[SceneGraph]) -> SceneGraph
pub fn merge_scenes(&self, scenes: &[SceneGraph]) -> SceneGraph
Merge multiple scene graphs into one, deduplicating objects that share
the same id.